"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ProjectType(str, Enum):
    r"""Enum for OWASP project types."""

    CODE = "code"
    DOCUMENTATION = "documentation"
    OTHER = "other"
    TOOL = "tool"
