"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class MemberTypedDict(TypedDict):
    r"""Schema for Member (minimal fields for list display)."""

    avatar_url: str
    created_at: datetime
    login: str
    name: str
    updated_at: datetime
    url: str


class Member(BaseModel):
    r"""Schema for Member (minimal fields for list display)."""

    avatar_url: str

    created_at: datetime

    login: str

    name: str

    updated_at: datetime

    url: str
