"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SnapshotTypedDict(TypedDict):
    r"""Schema for Snapshot (minimal fields for list display)."""

    created_at: datetime
    end_at: datetime
    key: str
    start_at: datetime
    title: str
    updated_at: datetime


class Snapshot(BaseModel):
    r"""Schema for Snapshot (minimal fields for list display)."""

    created_at: datetime

    end_at: datetime

    key: str

    start_at: datetime

    title: str

    updated_at: datetime
