"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SponsorTypedDict(TypedDict):
    r"""Schema for Sponsor (minimal fields for list display)."""

    image_url: str
    key: str
    name: str
    sponsor_type: str
    url: str


class Sponsor(BaseModel):
    r"""Schema for Sponsor (minimal fields for list display)."""

    image_url: str

    key: str

    name: str

    sponsor_type: str

    url: str
