"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IssueState(str, Enum):
    r"""Issue state choices."""

    OPEN = "open"
    CLOSED = "closed"
