"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issuestate import IssueState
from datetime import datetime
from owasp_nest.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import TypedDict


class SnapshotIssueTypedDict(TypedDict):
    r"""Schema for Snapshot Issue (used in list endpoints)."""

    created_at: datetime
    state: IssueState
    r"""Issue state choices."""
    title: str
    updated_at: datetime
    url: str
    organization_login: Nullable[str]
    repository_name: Nullable[str]


class SnapshotIssue(BaseModel):
    r"""Schema for Snapshot Issue (used in list endpoints)."""

    created_at: datetime

    state: IssueState
    r"""Issue state choices."""

    title: str

    updated_at: datetime

    url: str

    organization_login: Nullable[str]

    repository_name: Nullable[str]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m
