"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .milestone import Milestone, MilestoneTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedMilestoneTypedDict(TypedDict):
    current_page: int
    r"""Current page number"""
    has_next: bool
    r"""Whether there is a next page"""
    has_previous: bool
    r"""Whether there is a previous page"""
    items: List[MilestoneTypedDict]
    total_count: int
    r"""Total number of items"""
    total_pages: int
    r"""Total number of pages"""


class PagedMilestone(BaseModel):
    current_page: int
    r"""Current page number"""

    has_next: bool
    r"""Whether there is a next page"""

    has_previous: bool
    r"""Whether there is a previous page"""

    items: List[Milestone]

    total_count: int
    r"""Total number of items"""

    total_pages: int
    r"""Total number of pages"""
