"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SnapshotDetailTypedDict(TypedDict):
    r"""Detail schema for Snapshot (used in single item endpoints)."""

    created_at: datetime
    end_at: datetime
    key: str
    start_at: datetime
    title: str
    updated_at: datetime
    new_chapters_count: int
    new_issues_count: int
    new_projects_count: int
    new_releases_count: int
    new_users_count: int


class SnapshotDetail(BaseModel):
    r"""Detail schema for Snapshot (used in single item endpoints)."""

    created_at: datetime

    end_at: datetime

    key: str

    start_at: datetime

    title: str

    updated_at: datetime

    new_chapters_count: int

    new_issues_count: int

    new_projects_count: int

    new_releases_count: int

    new_users_count: int
