"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issuestate import IssueState
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class IssueDetailTypedDict(TypedDict):
    r"""Detail schema for Issue (used in single item endpoints)."""

    created_at: datetime
    state: IssueState
    r"""Issue state choices."""
    title: str
    updated_at: datetime
    url: str
    body: str


class IssueDetail(BaseModel):
    r"""Detail schema for Issue (used in single item endpoints)."""

    created_at: datetime

    state: IssueState
    r"""Issue state choices."""

    title: str

    updated_at: datetime

    url: str

    body: str
