"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ProjectLevel(str, Enum):
    r"""Enum for OWASP project levels."""

    OTHER = "other"
    INCUBATOR = "incubator"
    LAB = "lab"
    PRODUCTION = "production"
    FLAGSHIP = "flagship"
