"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SponsorDetailTypedDict(TypedDict):
    r"""Detail schema for Sponsor (used in single item endpoints)."""

    image_url: str
    key: str
    name: str
    sponsor_type: str
    url: str
    description: str
    is_member: bool
    job_url: str
    member_type: str


class SponsorDetail(BaseModel):
    r"""Detail schema for Sponsor (used in single item endpoints)."""

    image_url: str

    key: str

    name: str

    sponsor_type: str

    url: str

    description: str

    is_member: bool

    job_url: str

    member_type: str
