"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class MemberDetailTypedDict(TypedDict):
    r"""Detail schema for Member (used in single item endpoints)."""

    avatar_url: str
    created_at: datetime
    login: str
    name: str
    updated_at: datetime
    url: str
    bio: str
    company: str
    followers_count: int
    following_count: int
    location: str
    public_repositories_count: int
    title: str
    twitter_username: str


class MemberDetail(BaseModel):
    r"""Detail schema for Member (used in single item endpoints)."""

    avatar_url: str

    created_at: datetime

    login: str

    name: str

    updated_at: datetime

    url: str

    bio: str

    company: str

    followers_count: int

    following_count: int

    location: str

    public_repositories_count: int

    title: str

    twitter_username: str
