"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "owasp-nest"
__version__: str = "0.4.1"
__openapi_doc_version__: str = "0.3.6"
__gen_version__: str = "2.852.1"
__user_agent__: str = "speakeasy-sdk/python 0.4.1 2.852.1 0.3.6 owasp-nest"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
