"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from owasp_nest import models, utils
from owasp_nest._hooks import HookContext
from owasp_nest.types import OptionalNullable, UNSET
from owasp_nest.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Events(BaseSDK):
    def list_events(
        self,
        *,
        latitude_gte: OptionalNullable[float] = UNSET,
        latitude_lte: OptionalNullable[float] = UNSET,
        longitude_gte: OptionalNullable[float] = UNSET,
        longitude_lte: OptionalNullable[float] = UNSET,
        category: OptionalNullable[List[models.Category]] = UNSET,
        ordering: OptionalNullable[models.ListEventsOrdering] = UNSET,
        is_upcoming: OptionalNullable[bool] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedEvent:
        r"""List events

        Retrieve a paginated list of OWASP events.

        :param latitude_gte: Latitude greater than or equal to
        :param latitude_lte: Latitude less than or equal to
        :param longitude_gte: Longitude greater than or equal to
        :param longitude_lte: Longitude less than or equal to
        :param category: Filter events by category
        :param ordering: Ordering field
        :param is_upcoming: Filter for upcoming events
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListEventsRequest(
            latitude_gte=latitude_gte,
            latitude_lte=latitude_lte,
            longitude_gte=longitude_gte,
            longitude_lte=longitude_lte,
            category=category,
            ordering=ordering,
            is_upcoming=is_upcoming,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/events/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_events",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedEvent, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_events_async(
        self,
        *,
        latitude_gte: OptionalNullable[float] = UNSET,
        latitude_lte: OptionalNullable[float] = UNSET,
        longitude_gte: OptionalNullable[float] = UNSET,
        longitude_lte: OptionalNullable[float] = UNSET,
        category: OptionalNullable[List[models.Category]] = UNSET,
        ordering: OptionalNullable[models.ListEventsOrdering] = UNSET,
        is_upcoming: OptionalNullable[bool] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedEvent:
        r"""List events

        Retrieve a paginated list of OWASP events.

        :param latitude_gte: Latitude greater than or equal to
        :param latitude_lte: Latitude less than or equal to
        :param longitude_gte: Longitude greater than or equal to
        :param longitude_lte: Longitude less than or equal to
        :param category: Filter events by category
        :param ordering: Ordering field
        :param is_upcoming: Filter for upcoming events
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListEventsRequest(
            latitude_gte=latitude_gte,
            latitude_lte=latitude_lte,
            longitude_gte=longitude_gte,
            longitude_lte=longitude_lte,
            category=category,
            ordering=ordering,
            is_upcoming=is_upcoming,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/events/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_events",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedEvent, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def get_event(
        self,
        *,
        event_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EventDetail:
        r"""Get event

        Retrieve an event details.

        :param event_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetEventRequest(
            event_id=event_id,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/events/{event_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_event",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EventDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.EventErrorData, http_res)
            raise models.EventError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def get_event_async(
        self,
        *,
        event_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EventDetail:
        r"""Get event

        Retrieve an event details.

        :param event_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetEventRequest(
            event_id=event_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/events/{event_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_event",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EventDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.EventErrorData, http_res)
            raise models.EventError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)
