"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class Category(str, Enum):
    r"""Event category."""

    APPSEC_DAYS = "appsec_days"
    GLOBAL = "global"
    OTHER = "other"
    PARTNER = "partner"
