"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class MemberType(str, Enum):
    r"""Member type choices."""

    PLATINUM = "Platinum"
    GOLD = "Gold"
    SILVER = "Silver"
