"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class RepositoryTypedDict(TypedDict):
    r"""Schema for Repository (minimal fields for list display)."""

    created_at: datetime
    name: str
    updated_at: datetime


class Repository(BaseModel):
    r"""Schema for Repository (minimal fields for list display)."""

    created_at: datetime

    name: str

    updated_at: datetime
